@@ -519,51 +519,6 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
     it_behaves_like 'it supports with_message', valid_values: possible_values
 
-    if active_model_3_2?
-      context '+ strict' do
-        context 'when the validation specifies strict' do
-          it 'matches when the given values match the valid values' do
-            builder = build_object_allowing(
-              possible_values,
-              validation_options: { strict: true },
-            )
-
-            # rubocop:disable Style/SymbolProc
-            expect_to_match_on_values(builder, possible_values) do |matcher|
-              matcher.strict
-            end
-            # rubocop:enable Style/SymbolProc
-          end
-
-          it 'does not match when the given values do not match the valid values' do
-            builder = build_object_allowing(
-              possible_values,
-              validation_options: { strict: true },
-            )
-
-            values = add_outside_value_to(possible_values)
-            # rubocop:disable Style/SymbolProc
-            expect_not_to_match_on_values(builder, values) do |matcher|
-              matcher.strict
-            end
-            # rubocop:enable Style/SymbolProc
-          end
-        end
-
-        context 'when the validation does not specify strict' do
-          it 'does not match' do
-            builder = build_object_allowing(possible_values)
-
-            # rubocop:disable Style/SymbolProc
-            expect_not_to_match_on_values(builder, possible_values) do |matcher|
-              matcher.strict
-            end
-            # rubocop:enable Style/SymbolProc
-          end
-        end
-      end
-    end
-
     def expect_to_match_on_values(builder, values, &block)
       expect_to_match_in_array(builder, values, &block)
     end
@@ -617,6 +572,22 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
       expect_to_match_on_values(builder, possible_values)
     end
 
+    it 'matches given a beginless range that covers the possible values' do
+      builder = build_object_allowing(possible_values)
+      expect_to_match_on_values(
+        builder,
+        Range.new(nil, possible_values.last),
+      )
+    end
+
+    it 'matches given a endless range that covers the possible values' do
+      builder = build_object_allowing(possible_values)
+      expect_to_match_on_values(
+        builder,
+        Range.new(possible_values.first, nil),
+      )
+    end
+
     it 'does not match given a range whose start value falls outside valid range' do
       builder = build_object_allowing(possible_values)
       expect_not_to_match_on_values(
@@ -675,51 +646,6 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
     it_behaves_like 'it supports with_message', valid_values: possible_values
 
-    if active_model_3_2?
-      context '+ strict' do
-        context 'when the validation specifies strict' do
-          it 'matches when the given range matches the range in the validation' do
-            builder = build_object_allowing(
-              possible_values,
-              validation_options: { strict: true },
-            )
-
-            # rubocop:disable Style/SymbolProc
-            expect_to_match_on_values(builder, possible_values) do |matcher|
-              matcher.strict
-            end
-            # rubocop:enable Style/SymbolProc
-          end
-
-          it 'matches when the given range does not match the range in the validation' do
-            builder = build_object_allowing(
-              possible_values,
-              validation_options: { strict: true },
-            )
-
-            range = Range.new(possible_values.first, possible_values.last + 1)
-            # rubocop:disable Style/SymbolProc
-            expect_not_to_match_on_values(builder, range) do |matcher|
-              matcher.strict
-            end
-            # rubocop:enable Style/SymbolProc
-          end
-        end
-
-        context 'when the validation does not specify strict' do
-          it 'does not match' do
-            builder = build_object_allowing(possible_values)
-
-            # rubocop:disable Style/SymbolProc
-            expect_not_to_match_on_values(builder, possible_values) do |matcher|
-              matcher.strict
-            end
-            # rubocop:enable Style/SymbolProc
-          end
-        end
-      end
-    end
-
     def expect_to_match_on_values(builder, range, &block)
       expect_to_match_in_range(builder, range, &block)
     end
@@ -890,7 +816,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
     context 'against a polymorphic association' do
       it 'matches when the subject configures validate_inclusion_of' do
         define_model(:issue, severity_id: :integer, severity_type: :string) do
-          belongs_to :severity, polymorphic: true
+          belongs_to :severity, polymorphic: true, optional: true
           validates_inclusion_of :severity_type, in: %w(Low Medium High)
         end
         define_model(:high)
@@ -902,7 +828,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       it 'does not match when subject does not set validate_inclusion_of' do
         define_model(:issue, severity_id: :integer, severity_type: :string) do
-          belongs_to :severity, polymorphic: true
+          belongs_to :severity, polymorphic: true, optional: true
         end
         define_model(:high)
         define_model(:medium)
