@@ -331,10 +331,11 @@ it is not nil, but this could not be proved.
         expect(&assertion).to fail_with_message(<<~MESSAGE)
 Expected Example not to validate that :attr looks like an integer, but
 this could not be proved.
-  After setting :attr to ‹"0.1"›, the matcher expected the Example to be
-  valid, but it was invalid instead, producing these validation errors:
+  After setting :attr to ‹"abcd"›, the matcher expected the Example to
+  be valid, but it was invalid instead, producing these validation
+  errors:
 
-  * attr: ["must be an integer"]
+  * attr: ["is not a number"]
         MESSAGE
       end
 
@@ -351,7 +352,7 @@ this could not be proved.
             expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr looks like an integer, but this
 could not be proved.
-  After setting :attr to ‹"0.1"› -- which was read back as ‹"1"› -- the
+  After setting :attr to ‹"abcd"› -- which was read back as ‹"1"› -- the
   matcher expected the Example to be invalid, but it was valid instead.
 
   As indicated in the message above, :attr seems to be changing certain
@@ -410,10 +411,11 @@ could not be proved.
         expect(&assertion).to fail_with_message(<<~MESSAGE)
 Expected Example not to validate that :attr looks like an odd number,
 but this could not be proved.
-  After setting :attr to ‹"2"›, the matcher expected the Example to be
-  valid, but it was invalid instead, producing these validation errors:
+  After setting :attr to ‹"abcd"›, the matcher expected the Example to
+  be valid, but it was invalid instead, producing these validation
+  errors:
 
-  * attr: ["must be odd"]
+  * attr: ["is not a number"]
         MESSAGE
       end
 
@@ -531,10 +533,11 @@ this could not be proved.
         expect(&assertion).to fail_with_message(<<~MESSAGE)
 Expected Example not to validate that :attr looks like an even number,
 but this could not be proved.
-  After setting :attr to ‹"1"›, the matcher expected the Example to be
-  valid, but it was invalid instead, producing these validation errors:
+  After setting :attr to ‹"abcd"›, the matcher expected the Example to
+  be valid, but it was invalid instead, producing these validation
+  errors:
 
-  * attr: ["must be even"]
+  * attr: ["is not a number"]
         MESSAGE
       end
 
@@ -1984,6 +1987,56 @@ could not be proved.
     end
   end
 
+  describe 'using in the negative form without numericality validations' do
+    context 'when qualified with is_greater_than' do
+      it 'accepts' do
+        record = (define_model :example, attr: :integer).new
+
+        expect(record).not_to validate_numericality.is_greater_than(18)
+      end
+    end
+
+    context 'when qualified with is_greater_than_or_equal_to' do
+      it 'accepts' do
+        record = (define_model :example, attr: :integer).new
+
+        expect(record).not_to validate_numericality.is_greater_than_or_equal_to(18)
+      end
+    end
+
+    context 'when qualified with is_less_than_or_equal_to' do
+      it 'accepts' do
+        record = (define_model :example, attr: :integer).new
+
+        expect(record).not_to validate_numericality.is_less_than_or_equal_to(18)
+      end
+    end
+
+    context 'when qualified with is_less_than' do
+      it 'accepts' do
+        record = (define_model :example, attr: :integer).new
+
+        expect(record).not_to validate_numericality.is_less_than(18)
+      end
+    end
+
+    context 'when qualified with is_equal_to' do
+      it 'accepts' do
+        record = (define_model :example, attr: :integer).new
+
+        expect(record).not_to validate_numericality.is_equal_to(18)
+      end
+    end
+
+    context 'when qualified with is_other_than' do
+      it 'accepts' do
+        record = (define_model :example, attr: :integer).new
+
+        expect(record).not_to validate_numericality.is_other_than(18)
+      end
+    end
+  end
+
   describe '#description' do
     context 'qualified with nothing' do
       it 'describes that it allows numbers' do
